@@ -39,6 +39,9 @@ ArrayT = Union[List[Any], Tuple[Any, ...]]
 # Send objects with missing keys to the end when sorting a list.
 MAX_CH = chr(0x10FFFF)
 
+# Unique object for use with the uniq filter.
+MISSING = object()
+
 
 def _str_if_not(val: object) -> str:
     if not isinstance(val, str):
@@ -173,7 +176,7 @@ def sort_natural(sequence: ArrayT, key: object = None) -> List[object]:
 def where(sequence: ArrayT, attr: object, value: object = None) -> List[object]:
     """Creates an array including only the objects with a given property value,
     or any truthy value by default."""
-    if value:
+    if value is not None and not is_undefined(value):
         return [itm for itm in sequence if _getitem(itm, attr) == value]
 
     return [itm for itm in sequence if _getitem(itm, attr) not in (False, None)]
@@ -192,6 +195,8 @@ def uniq(sequence: ArrayT, key: object = None) -> List[object]:
         for obj in sequence:
             try:
                 item = obj[key]
+            except KeyError:
+                item = MISSING
             except TypeError as err:
                 raise FilterArgumentError(
                     f"can't read property '{key}' of {obj}"
